------------------------------------------------------------------------
--	Barrel
--	DataBroker display using minimap icons.
--	Copyright 2008, 2009 Copystring. All rights reserved.
-- Maintained by Phanx since 2012
--	http://www.wowace.com/addons/barrel/
------------------------------------------------------------------------

local BARREL, Barrel = ...

local LDB = LibStub("LibDataBroker-1.1")
local LDBI = LibStub("LibDBIcon-1.0")

------------------------------------------------------------------------

local L = setmetatable({}, { __index = function(t, k)
	local v = tostring(k)
	rawset(t, k, v)
	return v
end })

local GAME_LOCALE = GetLocale()

if GAME_LOCALE == "deDE" then
L["Angle"] = "Winkel"
L["Plugins"] = "Plugins"
L["Show data sources"] = "Datenquellen anzeigen"
L["Show launchers"] = "Starter anzeigen"
L["Show minimap icon"] = "Minikartensymbole anzeigen"
L["Show plugins that only provide an icon."] = "Zeigt die Plugins an, die nur ein Symbol bereitstellen."
L["Show plugins that provide text or other data."] = "Zeigt die Plugins an, die Text oder andere Daten bereitstellen."


elseif GAME_LOCALE == "esES" then
L["Angle"] = "Ángulo"
L["Plugins"] = "Plugins"
L["Show data sources"] = "Mostrar plugins con datos"
L["Show launchers"] = "Mostrar lanzadores"
L["Show minimap icon"] = "Mostrar icono del minimapa"
L["Show plugins that only provide an icon."] = "Muestra los plugins que muestran sólo un icono."
L["Show plugins that provide text or other data."] = "Muestra los plugins que muestran texto o otros datos."


elseif GAME_LOCALE == "esMX" then
L["Angle"] = "Ángulo"
L["Plugins"] = "Plugins"
L["Show data sources"] = "Mostrar plugins con datos"
L["Show launchers"] = "Mostrar lanzadores"
L["Show minimap icon"] = "Mostrar icono del minimapa"
L["Show plugins that only provide an icon."] = "Muestra los plugins que muestran sólo un icono."
L["Show plugins that provide text or other data."] = "Muestra los plugins que muestran texto o otros datos."


elseif GAME_LOCALE == "frFR" then
L["Angle"] = "Angle"
L["Plugins"] = "Plugins"
L["Show data sources"] = "Afficher sources de données"
L["Show launchers"] = "Afficher lanceurs"
L["Show minimap icon"] = "Afficher icône minicarte"
L["Show plugins that only provide an icon."] = "Afficher plugins qui montrent que d'une icône."
L["Show plugins that provide text or other data."] = "Afficher plugins qui montrent texte ou d'autres données."


elseif GAME_LOCALE == "itIT" then
L["Angle"] = "Angolo"
L["Plugins"] = "Plugins"
L["Show data sources"] = "Mostrare fonti di dati"
L["Show launchers"] = "Mostrare lanciatori"
L["Show minimap icon"] = "Mostrare icona sulla minimappa"
L["Show plugins that only provide an icon."] = "Mostrare plugins che mostrano solo un'icona."
L["Show plugins that provide text or other data."] = "Mostrare plugins che mostrano testo o altri dati."


elseif GAME_LOCALE == "ptBR" then
L["Angle"] = "Ângulo"
L["Plugins"] = "Plugins"
L["Show data sources"] = "Mostrar fontes de dados"
L["Show launchers"] = "Mostrar lançadores"
L["Show minimap icon"] = "Mostrar ícone no mini-mapa"
L["Show plugins that only provide an icon."] = "Mostrar plugins que mostram apenas um ícone."
L["Show plugins that provide text or other data."] = "Mostrar plugins que mostram texto ou outros dados."


elseif GAME_LOCALE == "ruRU" then
L["Angle"] = "Угол"
L["Plugins"] = "Плагины"
L["Show data sources"] = "Показать источники данных"
L["Show launchers"] = "Показать пусковых установок"
L["Show minimap icon"] = "Показать иконки на мини-карте"
L["Show plugins that only provide an icon."] = "Показать плагины, которые показывают только иконку."
L["Show plugins that provide text or other data."] = "Показать плагинов, которые показывают, текст или другие данные."


elseif GAME_LOCALE == "koKR" then
L["Angle"] = "직각"
L["Plugins"] = "플러그인"
L["Show data sources"] = "데이터 소스 표시"
L["Show launchers"] = "실행 항목만 표시"
L["Show minimap icon"] = "미니맵 아이콘 표시"


elseif GAME_LOCALE == "zhCN" then
L["Angle"] = "角"
L["Plugins"] = "组件"
L["Show data sources"] = "显示数据源"
L["Show launchers"] = "显示仅运行"
L["Show minimap icon"] = "显示小地圖圖示"


elseif GAME_LOCALE == "zhTW" then
L["Angle"] = "角"
L["Plugins"] = "插件"
L["Show data sources"] = "顯示數據源"
L["Show launchers"] = "顯示僅運行"
L["Show minimap icon"] = "顯示小地圖圖示"


end

------------------------------------------------------------------------

function Barrel:LoadOptions()
	self.db = LibStub("AceDB-3.0"):New("BarrelDB", {
		profile = {
			showDataSources = true,
			showLaunchers = true,
		}
	}, "Default")

	self.options = {
		type = "group",
		name = BARREL,
		args = {
			showDataSources = {
				order = 1,
				name = L["Show data sources"],
				desc = L["Show plugins that provide text or other data."],
				width = "full",
				type = "toggle",
				get = function()
					return self.db.profile.showDataSources
				end,
				set = function(info, value)
					self.db.profile.showDataSources = value
					self:ToggleDataSources()
				end,
			},
			showLaunchers = {
				order = 2,
				name = L["Show launchers"],
				desc = L["Show plugins that only provide an icon."],
				width = "full",
				type = "toggle",
				get = function()
					return self.db.profile.showLaunchers
				end,
				set = function(info, value)
					self.db.profile.showLaunchers = value
					self:ToggleLaunchers()
				end,
			},
			pluginHeader = {
				name = "\n" .. NORMAL_FONT_COLOR_CODE .. L["Plugins"],
				type = "description",
				fontSize = "large",
				order = 3,
			},
		},
	}

	self.profileOptions = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)

	local Registry = LibStub("AceConfigRegistry-3.0")
	Registry:RegisterOptionsTable(BARREL, self.options)
	Registry:RegisterOptionsTable(BARREL.."Profile", self.profileOptions)

	local Dialog = LibStub("AceConfigDialog-3.0")
	Dialog:AddToBlizOptions(BARREL, BARREL)
	Dialog:AddToBlizOptions(BARREL.."Profile", self.profileOptions.name, BARREL)

	SLASH_BARREL1 = "/br"
	SLASH_BARREL2 = "/barrel"

	SlashCmdList.BARREL = function()
		InterfaceOptionsFrame_OpenToCategory(BARREL)
		InterfaceOptionsFrame_OpenToCategory(BARREL) -- duplication intentional
	end
end

------------------------------------------------------------------------

function Barrel:AddOptionsForPlugin(name)
	local pluginName = name
	local buttonName = "Barrel_" .. name
	local disabledName = GRAY_FONT_COLOR_CODE .. name
	local pluginType = LDB:GetDataObjectByName(pluginName).type

	local function IsDisabled()
		return (pluginType == "data source" and not self.db.profile.showDataSources)
		or (pluginType == "launcher" and not self.db.profile.showLaunchers)
	end

	self.options.args[pluginName] = {
		name = function()
			return IsDisabled() and disabledName or pluginName
		end,
		type = "group",
		disabled = IsDisabled,
		args = {
			enable = {
				name = L["Show minimap icon"],
				order = 1,
				width = "full",
				type = "toggle",
				get = function(info)
					return not self.db.profile[pluginName].hide
				end,
				set = function(info, value)
					if value then
						self:EnableDataObject(pluginName)
					else
						self:DisableDataObject(pluginName)
					end
					self.db.profile[pluginName].hide = not value
				end,
			},
			angle = {
				name = L["Angle"],
				order = 2,
				width = "double",
				type = "range",
				min = 0,
				max = 360,
				step = 1,
				get = function()
					return self.db.profile[pluginName].minimapPos
				end,
				set = function(info, value)
					self.db.profile[pluginName].minimapPos = value
					LDBI:Refresh(buttonName)
				end,
			},
			-- TODO: add info text when disabled?
		},
	}
end