------------------------------------------------------------------------
--	Barrel
--	DataBroker display using minimap icons.
--	Copyright 2008, 2009 Copystring. All rights reserved.
--	http://www.wowace.com/addons/barrel/
------------------------------------------------------------------------

local BARREL, Barrel = ...

local LDB = LibStub("LibDataBroker-1.1")
local LDBI = LibStub("LibDBIcon-1.0")

local dataObjects = {}

------------------------------------------------------------------------

local eventFrame = CreateFrame("Frame")
eventFrame:RegisterEvent("PLAYER_LOGIN")
eventFrame:SetScript("OnEvent", function(self)
	Barrel:LoadOptions()
	Barrel.LoadOptions = nil

	for name, dataobj in LDB:DataObjectIterator() do
		Barrel:LibDataBroker_DataObjectCreated(nil, name, dataobj)
	end

	LDB.RegisterCallback(Barrel, "LibDataBroker_DataObjectCreated")
	LDB.RegisterCallback(Barrel, "LibDataBroker_AttributeChanged__icon")
	LDB.RegisterCallback(Barrel, "LibDataBroker_AttributeChanged__iconCoords")

	self:UnregisterEvent("PLAYER_LOGIN")
	self:SetScript("OnEvent", nil)
end)

------------------------------------------------------------------------

function Barrel:LibDataBroker_AttributeChanged__icon(event, name, key, value, dataobj)
	local obj = LDBI.objects["Barrel_"..name]
	if obj then
		obj.icon:SetTexture(value)
	end
end

function Barrel:LibDataBroker_AttributeChanged__iconCoords(event, name, key, value, dataobj)
	local obj = LDBI.objects["Barrel_"..name]
	if obj then
		if type(value) == "table" then
			obj.icon:SetTexCoord(unpack(value))
		else
			obj.icon:SetTexCoord(0, 1, 0, 1)
		end
	end
end

function Barrel:LibDataBroker_DataObjectCreated(event, name, dataobj)
	if not dataobj.icon then
		dataobj.icon = "Interface\\ICONS\\INV_Misc_QuestionMark"
	end

	local t = dataobj.type
	if t == "data source" or t == "launcher" then
		self:CreateDataObject(name, dataobj)
	end
end

------------------------------------------------------------------------

function Barrel:CreateDataObject(name, dataobj)
	if dataObjects[name] then return end

	dataObjects[name] = dataobj

	self:AddOptionsForPlugin(name)

	if not self.db.profile[name] then
		self.db.profile[name] = {}
	end
	LDBI:Register("Barrel_"..name, dataobj, self.db.profile[name])

	if not self.db.profile[name].hide then
		self:EnableDataObject(name)
	end
end

function Barrel:EnableDataObject(name)
	local dataobj = dataObjects[name]
	if dataobj.icon == nil
	or (dataobj.type == "data source" and not self.db.profile.showDataSources)
	or (dataobj.type == "launcher" and not self.db.profile.showLaunchers) then
		return
	end
	LDBI:Show("Barrel_"..name)
end

function Barrel:DisableDataObject(name)
	LDBI:Hide("Barrel_"..name)
end

------------------------------------------------------------------------

function Barrel:ToggleDataSources()
	local func = self.db.profile.showDataSources and self.EnableDataObject or self.DisableDataObject
	for name, obj in pairs(dataObjects) do
		if obj.type == "data source" then
			func(self, name)
		end
	end
end

function Barrel:ToggleLaunchers()
	local func = self.db.profile.showLaunchers and self.EnableDataObject or self.DisableDataObject
	for name, obj in pairs(dataObjects) do
		if obj.type == "launcher" then
			func(self, name)
		end
	end
end